@@ -16,7 +16,7 @@ INFURA_TOKEN = os.environ.get("INFURA_TOKEN")
     [f"https://mainnet.infura.io/v3/{INFURA_TOKEN}", "mainnet"],
     [f"https://rinkeby.infura.io/v3/{INFURA_TOKEN}", "rinkeby"],
     ("http://localhost:8545", "spree"),
-    ("https://rpc-mumbai.matic.today", "mumbai"),
+    (f"https://polygon-mumbai.infura.io/v3/{INFURA_TOKEN}", "mumbai"),
     ("https://alfajores-forno.celo-testnet.org", "celo-alfajores"),
     ("https://baklava-forno.celo-testnet.org", "celo-baklava")
 ])
